==> kcontrol-ldap-controller-trinity_14.1.1.orig.tar.xz: kcmldapcontroller-trinity-14.1.1/src/secondaryrealmwizard/realmconfigpage.cpp <==
/***************************************************************************
 *   Copyright (C) 2012 by Timothy Pearson                                 *
 *   kb9vqf@pearsoncomputing.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <tqstringlist.h>
#include <tqlabel.h>
#include <tqmap.h>

#include <tdeapplication.h>
#include <ksimpleconfig.h>
#include <tdelocale.h>
#include <kdebug.h>
#include <kstandarddirs.h>
#include <kiconloader.h>
#include <dcopclient.h>
#include <kprocess.h>
#include <klineedit.h>
#include <ktextedit.h>
#include <kwizard.h>
#include <kdialogbase.h>
#include <tqpushbutton.h>

#include "realmconfigpage.h"

SecondaryRealmConfigPage::SecondaryRealmConfigPage(TQWidget *parent, const char *name ) : SecondaryRealmConfigPageDlg(parent,name) {

	px_introSidebar->setPixmap(UserIcon("kcmldapcontroller_step1.png"));

	connect(txtRealmName, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(validateEntries()));
	connect(txtKDC, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(validateEntries()));
	connect(txtAdminServer, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(validateEntries()));

	connect(txtRealmName, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(realmNameChanged()));

	m_parentWizard = dynamic_cast<KWizard*>(parent);
	m_parentDialog = dynamic_cast<KDialogBase*>(parent);
}

SecondaryRealmConfigPage::~SecondaryRealmConfigPage() {
	// 
}

void SecondaryRealmConfigPage::validateEntries() {
	if (m_parentWizard) {
		if ((txtRealmName->text() != "") && (txtKDC->text() != "") && (txtAdminServer->text() != "")) {
			m_parentWizard->nextButton()->setEnabled(true);
		}
		else {
			m_parentWizard->nextButton()->setEnabled(false);
		}
	}
	if (m_parentDialog) {
		if ((txtRealmName->text() != "") && (txtKDC->text() != "") && (txtAdminServer->text() != "")) {
			m_parentDialog->enableButton(KDialogBase::Ok, true);
		}
		else {
			m_parentDialog->enableButton(KDialogBase::Ok, false);
		}
	}
}

void SecondaryRealmConfigPage::realmNameChanged() {
	TQString realmName = txtRealmName->text();
	txtRealmName->setText(realmName.upper());

	TQString defaultDomainAliases;
	defaultDomainAliases = realmName.lower();
	defaultDomainAliases += "\n";
	defaultDomainAliases += ".";
	defaultDomainAliases += realmName.lower();
	txtDomains->setText(defaultDomainAliases);
}

#include "realmconfigpage.moc"

==> kcontrol-ldap-controller-trinity_14.1.5.orig.tar.xz: kcmldapcontroller-trinity-14.1.5/src/secondaryrealmwizard/realmconfigpage.cpp <==
/***************************************************************************
 *   Copyright (C) 2012 by Timothy Pearson                                 *
 *   kb9vqf@pearsoncomputing.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <tqstringlist.h>
#include <tqlabel.h>
#include <tqmap.h>

#include <tdeapplication.h>
#include <ksimpleconfig.h>
#include <tdelocale.h>
#include <kdebug.h>
#include <kstandarddirs.h>
#include <kiconloader.h>
#include <dcopclient.h>
#include <kprocess.h>
#include <klineedit.h>
#include <ktextedit.h>
#include <kwizard.h>
#include <kdialogbase.h>
#include <tqpushbutton.h>

#include "realmconfigpage.h"

SecondaryRealmConfigPage::SecondaryRealmConfigPage(TQWidget *parent, const char *name ) : SecondaryRealmConfigPageDlg(parent,name) {

	px_introSidebar->setPixmap(UserIcon("kcmldapcontroller_step1.png"));

	connect(txtRealmName, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(validateEntries()));
	connect(txtKDC, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(validateEntries()));
	connect(txtAdminServer, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(validateEntries()));

	connect(txtRealmName, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(realmNameChanged()));

	m_parentWizard = dynamic_cast<KWizard*>(parent);
	m_parentDialog = dynamic_cast<KDialogBase*>(parent);
}

SecondaryRealmConfigPage::~SecondaryRealmConfigPage() {
	// 
}

void SecondaryRealmConfigPage::validateEntries() {
	if (m_parentWizard) {
		if ((txtRealmName->text() != "") && (txtKDC->text() != "") && (txtAdminServer->text() != "")) {
			m_parentWizard->nextButton()->setEnabled(true);
		}
		else {
			m_parentWizard->nextButton()->setEnabled(false);
		}
	}
	if (m_parentDialog) {
		if ((txtRealmName->text() != "") && (txtKDC->text() != "") && (txtAdminServer->text() != "")) {
			m_parentDialog->enableButton(KDialogBase::Ok, true);
		}
		else {
			m_parentDialog->enableButton(KDialogBase::Ok, false);
		}
	}
}

void SecondaryRealmConfigPage::realmNameChanged() {
	TQString realmName = txtRealmName->text();
	txtRealmName->setText(realmName.upper());

	TQString defaultDomainAliases;
	defaultDomainAliases = realmName.lower();
	defaultDomainAliases += "\n";
	defaultDomainAliases += ".";
	defaultDomainAliases += realmName.lower();
	txtDomains->setText(defaultDomainAliases);
}

#include "realmconfigpage.moc"
